ResolvedOrigin

Struct ResolvedOrigin 

pub struct ResolvedOrigin { /* private fields */ }
An resolved representation of RawOrigin<'a>

This representation is used to store the pre-calculated entity IDs derived from a borrowed RawOrigin<'a> in order to speed the lookup of origin tags attached to each individual entity ID that comprises an origin.

This type can be cheaply cloned and shared across threads.

Implementations

Source

impl ResolvedOrigin

pub fn from_parts( cardinality: Option<OriginTagCardinality>, process_id: Option<EntityId>, local_data: Option<EntityId>, pod_uid: Option<EntityId>, resolved_external_data: Option<ResolvedExternalData>, ) -> Self

Creates a new ResolvedOrigin from the given parts.

pub fn cardinality(&self) -> Option<OriginTagCardinality>

Returns the cardinality of the origin.

pub fn process_id(&self) -> Option<&EntityId>

Returns the process ID of the origin.

pub fn local_data(&self) -> Option<&EntityId>

Returns the Local Data-based entity ID of the origin.

pub fn pod_uid(&self) -> Option<&EntityId>

Returns the pod UID of the origin.

pub fn resolved_external_data(&self) -> Option<&ResolvedExternalData>

Returns the resolved External Data of the origin.